@@ -1,12 +1,14 @@
 package Form::Tiny::Hook;
-$Form::Tiny::Hook::VERSION = '2.18_01'; # TRIAL
-$Form::Tiny::Hook::VERSION = '2.1801';
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
 use Types::Standard qw(Enum CodeRef Bool);
 
+use namespace::clean;
+
+our $VERSION = '2.01';
+
 use constant {
 	HOOK_REFORMAT => 'reformat',
 	HOOK_BEFORE_MANGLE => 'before_mangle',
@@ -25,14 +27,14 @@ my @hooks = (
 	HOOK_AFTER_ERROR,
 );
 
-has 'hook' => (
-	is => 'ro',
+has "hook" => (
+	is => "ro",
 	isa => Enum [@hooks],
 	required => 1,
 );
 
-has 'code' => (
-	is => 'ro',
+has "code" => (
+	is => "ro",
 	isa => CodeRef,
 	required => 1,
 );
@@ -69,21 +71,18 @@ Form::Tiny::Hook - a representation of a hook
 
 	# in your form class
 
-	# the following will be coerced into Form::Tiny::Hook
+	# the following will be coerced into Form::Tiny::Filter
 	form_hook before_validation => $coderef;
 
 =head1 DESCRIPTION
 
-This is a simple class which stores a hook type together with a code reference
-which will be fired on that stage. See L<Form::Tiny::Manual/"Hooks"> for
-details.
+This is a simple class which stores a hook type together with a code reference which will be fired on that stage. See L<Form::Tiny::Manual/"Hooks"> for details.
 
 =head1 ATTRIBUTES
 
 =head2 hook
 
-A hook type. Currently available types are: C<reformat before_mangle
-before_validate after_validate cleanup after_error>.
+A hook type. Currently available types are: C<reformat before_mangle before_validate after_validate cleanup after_error>.
 
 Required.
 
@@ -95,14 +94,10 @@ Required.
 
 =head2 inherited
 
-A boolean - whether the hook should be inherited to child forms. True by
-default.
+A boolean - whether the hook should be inherited to child forms. True by default.
 
 =head1 METHODS
 
 =head2 is_modifying
 
-Given a hook object, this method will return a boolean value which indicates
-whether the hook is meant to be modifying the passed in value. If false, we
-should discard the return value of that hook's code reference.
-
+Given a hook object, this method will return a boolean value which indicates whether the hook is meant to be modifying the passed in value. If false, we should discard the return value of that hook's code reference.
