@@ -1,31 +1,32 @@
 package Form::Tiny::Path;
-$Form::Tiny::Path::VERSION = '2.18_01'; # TRIAL
-$Form::Tiny::Path::VERSION = '2.1801';
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
 use Carp qw(croak);
 use Types::Standard qw(ArrayRef);
 
+use namespace::clean;
+
+our $VERSION = '2.00';
+
 our $nesting_separator = q{.};
 our $array_marker = q{*};
 our $escape_character = q{\\};
 
-has 'path' => (
-	is => 'ro',
+has "path" => (
+	is => "ro",
 	isa => ArrayRef,
-	writer => '_set_path',
+	writer => "_set_path",
+	coerce => 1,
 	required => 1,
 );
 
-# Note: this clashes with 'meta' from Moo :/
-# will stay as it is though as long as it works (overrides the other meta)
-# properly, since can't know how much external code uses it
-has 'meta' => (
-	is => 'ro',
+has "meta" => (
+	is => "ro",
 	isa => ArrayRef,
-	writer => '_set_meta',
+	writer => "_set_meta",
+	lazy => 1,
 	required => 1,
 );
 
@@ -64,12 +65,12 @@ sub from_name
 	croak 'path specified was empty'
 		unless length $name;
 
-	# use custom escape character for path building
-	# (won't be mistaken for literal backslash)
 	my $escape = "\x00";
 	$name =~ s/(\Q$escape_character\E{1,2})/length $1 == 2 ? $escape_character : $escape/ge;
 
-	my @parts = split /(?<!$escape)\Q$nesting_separator\E/, $name, -1;
+	my $arr = quotemeta $array_marker;
+	my $sep = quotemeta $nesting_separator;
+	my @parts = split /(?<!$escape)$sep/, $name, -1;
 	my @meta;
 
 	for my $part (@parts) {
@@ -80,11 +81,7 @@ sub from_name
 			push @meta, 'HASH';
 		}
 	}
-
-	@parts = map {
-		s{ $escape ( \Q$nesting_separator\E | \Q$array_marker\E ) }{$1}gx;
-		$_
-	} @parts;
+	@parts = map { s/$escape($sep|$arr)/$1/ge; $_ } @parts;
 
 	return $self->new(path => \@parts, meta => \@meta);
 }
@@ -116,18 +113,20 @@ sub make_name_path
 {
 	my ($self, $prefix) = @_;
 
-	my @real_path = @{$self->path};
-	my $meta = $self->meta;
+	my @real_path;
+	my @path = @{$self->path};
+	my @meta = @{$self->meta};
 
-	@real_path = @real_path[0 .. $prefix]
-		if defined $prefix;
+	$prefix //= $#path;
+	for my $ind (0 .. $prefix) {
+		my $part = $path[$ind];
 
-	for my $ind (0 .. $#real_path) {
-		if ($meta->[$ind] ne 'ARRAY') {
-			$real_path[$ind] =~ s{
-				(\Q$escape_character\E | \Q$nesting_separator\E | \A\Q$array_marker\E\z)
-			}{$escape_character$1}gx;
-		}
+		$part =~ s/\Q$escape_character\E/$escape_character$escape_character/g;
+		$part =~ s/\Q$nesting_separator\E/$escape_character$nesting_separator/g;
+		$part =~ s/\A\Q$array_marker\E\z/$escape_character$array_marker/g
+			unless $meta[$ind] eq 'ARRAY';
+
+		push @real_path, $part;
 	}
 
 	return @real_path;
@@ -139,38 +138,4 @@ sub join
 	return join $nesting_separator, $self->make_name_path($prefix);
 }
 
-sub follow
-{
-	my ($self, $structure) = @_;
-
-	return undef if !ref $structure;
-
-	my @found = ($structure);
-	my @path = @{$self->path};
-	my @meta = @{$self->meta};
-	my $has_array = 0;
-
-	for my $ind (0 .. $#path) {
-		my $is_array = $meta[$ind] eq 'ARRAY';
-		my @new_found;
-
-		for my $item (@found) {
-			if ($is_array && ref $item eq 'ARRAY') {
-				push @new_found, @{$item};
-			}
-			elsif (ref $item eq 'HASH' && exists $item->{$path[$ind]}) {
-				push @new_found, $item->{$path[$ind]};
-			}
-		}
-
-		@found = @new_found;
-		$has_array ||= $is_array;
-	}
-
-	return $has_array
-		? \@found
-		: $found[0];
-}
-
 1;
-
